<?php
/**
 * Register membership custom post type
 */

if( !function_exists('listio_register_membership_type_init') ): 
    function listio_register_membership_type_init() {
        wp_enqueue_style('listio_plugin_style', PLUGIN_PATH . 'css/style.css', false, '1.0', 'all');
    }
endif;
add_action('init', 'listio_register_membership_type_init');

if( !function_exists('listio_register_membership_type') ): 
    function listio_register_membership_type() {
        register_post_type('membership', array(
            'labels' => array(
                'name'                  => __('Membership Plans','listio'),
                'singular_name'         => __('Membership Plan','listio'),
                'add_new'               => __('Add New Membership Plan','listio'),
                'add_new_item'          => __('Add Membership Plan','listio'),
                'edit'                  => __('Edit','listio'),
                'edit_item'             => __('Edit Membership Plan','listio'),
                'new_item'              => __('New Membership Plan','listio'),
                'view'                  => __('View','listio'),
                'view_item'             => __('View Membership Plan','listio'),
                'search_items'          => __('Search Membership Plans','listio'),
                'not_found'             => __('No Membership Plans found','listio'),
                'not_found_in_trash'    => __('No Membership Plans found in Trash','listio'),
                'parent'                => __('Parent Membership Plan', 'listio'),
            ),
            'public'                => true,
            'exclude_from_search '  => true,
            'has_archive'           => true,
            // 'rewrite'               => array('slug' => 'membership_plans'),
            'rewrite'               => array('slug' => _x('membership_plans', 'URL SLUG', 'listio')),
            'supports'              => array('title'),
            'can_export'            => true,
            'register_meta_box_cb'  => 'listio_add_membership_metaboxes',
            'menu_icon'             => PLUGIN_PATH . '/images/packages-icon.png'
        ));
    }
endif;
add_action('init', 'listio_register_membership_type');

/**
 * Add membership post type metaboxes
 */
if( !function_exists('listio_add_membership_metaboxes') ): 
    function listio_add_membership_metaboxes() {
        add_meta_box('membership-plan-features-section', __('Membership Plan Features', 'listio'), 'listio_membership_plan_features_render', 'membership', 'normal', 'default');
    }
endif;

if( !function_exists('listio_membership_plan_features_render') ): 
    function listio_membership_plan_features_render($post) {
        wp_nonce_field(PLUGIN_BASENAME, 'membership_noncename');

        $selected_unit = get_post_meta($post->ID, 'membership_billing_time_unit', true);
        $listio_membership_settings = get_option('listio_membership_settings');
        $currency = isset($listio_membership_settings['listio_payment_currency_field']) ? $listio_membership_settings['listio_payment_currency_field'] : '';

        print '
            <table width="100%" border="0" cellspacing="0" cellpadding="0">
                <tr>
                    <td width="33%" valign="top" align="left">
                        <div class="adminField">
                            <label for="membership_period">' . __('Membership Plan Period', 'listio') . '</label><br />
                            <input type="text" class="formInput" id="membership_period" name="membership_period" placeholder="' . __('Enter number of...', 'listio') . '" value="' . esc_attr(get_post_meta($post->ID, 'membership_period', true)) . '" />
                        </div>
                    </td>
                    <td width="33%" valign="top" align="left">
                        <div class="adminField">
                            <label for="membership_billing_time_unit">&nbsp;</label><br />
                            <select id="membership_billing_time_unit" name="membership_billing_time_unit">
                                <option value="day" ';
                                selected( $selected_unit, 'day' );
                                print '>' . __('Days', 'listio') . '</option>
                                <option value="week" ';
                                selected( $selected_unit, 'week' );
                                print '>' . __('Weeks', 'listio') . '</option>
                                <option value="month" ';
                                selected( $selected_unit, 'month' );
                                print '>' . __('Months', 'listio') . '</option>
                                <option value="year" ';
                                selected( $selected_unit, 'year' );
                                print '>' . __('Years', 'listio') . '</option>
                            </select>
                        </div>
                    </td>
                    <td width="33%" valign="top" align="left">&nbsp;</td>
                </tr>
                <tr>
                    <td width="33%" valign="top" align="left">
                        <div class="adminField">
                            <label for="membership_submissions_no">' . __('Number of Submissions', 'listio') . '</label><br />
                            <input type="text" class="formInput" id="membership_submissions_no" name="membership_submissions_no" placeholder="' . __('Enter the number of submissions', 'listio') . '" value="' . esc_attr(get_post_meta($post->ID, 'membership_submissions_no', true)) . '" />
                        </div>
                    </td>
                    <td width="33%" valign="top" align="left">
                        <p class="meta-options" style="padding-top: 15px;"> 
                            <input type="hidden" name="membership_unlim_submissions" value="">
                            <input type="checkbox" name="membership_unlim_submissions" value="1" ';
                            if (get_post_meta($post->ID, 'membership_unlim_submissions', true) == 1) {
                                print ' checked ';
                            }
                            print ' />
                            <label for="membership_unlim_submissions">' . __('Unlimited Submissions', 'listio') . '</label>
                        </p>
                    </td>
                    <td width="33%" valign="top" align="left">&nbsp;</td>
                </tr>
                <tr>
                    <td width="33%" valign="top" align="left">
                        <div class="adminField">
                            <label for="membership_featured_submissions_no">' . __('Number of Featured Submissions', 'listio') . '</label><br />
                            <input type="text" class="formInput" id="membership_featured_submissions_no" name="membership_featured_submissions_no" placeholder="' . __('Enter the number of featured submissions', 'listio') . '" value="' . esc_attr(get_post_meta($post->ID, 'membership_featured_submissions_no', true)) . '" />
                        </div>
                    </td>
                    <td width="33%" valign="top" align="left">&nbsp;</td>
                    <td width="33%" valign="top" align="left">&nbsp;</td>
                </tr>
                <tr>
                    <td width="33%" valign="top" align="left">
                        <div class="adminField">
                            <label for="membership_plan_price">' . __('Plan Price', 'listio') . ' (' . esc_html($currency) . ')</label><br />
                            <input type="text" class="formInput" id="membership_plan_price" name="membership_plan_price" placeholder="' . __('Enter the plan price', 'listio') . '" value="' . esc_attr(get_post_meta($post->ID, 'membership_plan_price', true)) . '" />
                        </div>
                    </td>
                    <td width="33%" valign="top" align="left">
                        <p class="meta-options" style="padding-top: 15px;"> 
                            <input type="hidden" name="membership_free_plan" value="">
                            <input type="checkbox" name="membership_free_plan" value="1" ';
                            if (get_post_meta($post->ID, 'membership_free_plan', true) == 1) {
                                print ' checked ';
                            }
                            print ' />
                            <label for="membership_free_plan">' . __('Free Plan', 'listio') . '</label>
                        </p>
                    </td>
                    <td width="33%" valign="top" align="left">&nbsp;</td>
                </tr>
            </table>';
    }
endif;

if( !function_exists('listio_membership_meta_save') ): 
    function listio_membership_meta_save($post_id) {
        $is_autosave = wp_is_post_autosave($post_id);
        $is_revision = wp_is_post_revision($post_id);
        $is_valid_nonce = (isset($_POST['membership_noncename']) && wp_verify_nonce($_POST['membership_noncename'], PLUGIN_BASENAME)) ? 'true' : 'false';

        if ($is_autosave || $is_revision || !$is_valid_nonce) {
            return;
        }

        if(isset($_POST['membership_billing_time_unit'])) {
            update_post_meta($post_id, 'membership_billing_time_unit', sanitize_text_field($_POST['membership_billing_time_unit']));
        }
        if(isset($_POST['membership_period'])) {
            update_post_meta($post_id, 'membership_period', sanitize_text_field($_POST['membership_period']));
        }
        if(isset($_POST['membership_submissions_no'])) {
            update_post_meta($post_id, 'membership_submissions_no', sanitize_text_field($_POST['membership_submissions_no']));
        }
        if(isset($_POST['membership_unlim_submissions'])) {
            update_post_meta($post_id, 'membership_unlim_submissions', sanitize_text_field($_POST['membership_unlim_submissions']));
        }
        if(isset($_POST['membership_featured_submissions_no'])) {
            update_post_meta($post_id, 'membership_featured_submissions_no', sanitize_text_field($_POST['membership_featured_submissions_no']));
        }
        if(isset($_POST['membership_plan_price'])) {
            update_post_meta($post_id, 'membership_plan_price', sanitize_text_field($_POST['membership_plan_price']));
        }
        if(isset($_POST['membership_free_plan'])) {
            update_post_meta($post_id, 'membership_free_plan', sanitize_text_field($_POST['membership_free_plan']));
        }
    }
endif;
add_action('save_post', 'listio_membership_meta_save');

if( !function_exists('listio_change_membership_default_title') ): 
    function listio_change_membership_default_title($title){
        $screen = get_current_screen();
        if ('membership' == $screen->post_type) {
            $title = __('Enter membership plan title here', 'listio');
        }
        return $title;
    }
endif;
add_filter('enter_title_here', 'listio_change_membership_default_title');
?>